@@ -64,7 +64,7 @@ class Exceptions:
 
 class AppflowClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html)
     """
 
@@ -73,7 +73,9 @@ class AppflowClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#can_paginate)
         """
 
@@ -83,11 +85,13 @@ class AppflowClient:
         connectorProfileName: str,
         connectorType: ConnectorTypeType,
         connectionMode: ConnectionModeType,
-        connectorProfileConfig: ConnectorProfileConfigTypeDef,
+        connectorProfileConfig: "ConnectorProfileConfigTypeDef",
         kmsArn: str = None
     ) -> CreateConnectorProfileResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.create_connector_profile)
+        Creates a new connector profile associated with your AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.create_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_connector_profile)
         """
 
@@ -104,7 +108,9 @@ class AppflowClient:
         tags: Dict[str, str] = None
     ) -> CreateFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.create_flow)
+        Enables your application to create a new flow using Amazon AppFlow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.create_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_flow)
         """
 
@@ -112,13 +118,17 @@ class AppflowClient:
         self, *, connectorProfileName: str, forceDelete: bool = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
+        Enables you to delete an existing connector profile.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_connector_profile)
         """
 
     def delete_flow(self, *, flowName: str, forceDelete: bool = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.delete_flow)
+        Enables your application to delete an existing flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.delete_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_flow)
         """
 
@@ -130,7 +140,10 @@ class AppflowClient:
         connectorProfileName: str = None
     ) -> DescribeConnectorEntityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
+        Provides details regarding the entity used with the connector, with a
+        description of the data model for each entity.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_entity)
         """
 
@@ -143,7 +156,10 @@ class AppflowClient:
         nextToken: str = None
     ) -> DescribeConnectorProfilesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
+        Returns a list of `connector-profile` details matching the provided `connector-
+        profile` names and `connector-types`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_profiles)
         """
 
@@ -151,13 +167,17 @@ class AppflowClient:
         self, *, connectorTypes: List[ConnectorTypeType] = None, nextToken: str = None
     ) -> DescribeConnectorsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.describe_connectors)
+        Describes the connectors vended by Amazon AppFlow for specified connector types.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.describe_connectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connectors)
         """
 
     def describe_flow(self, *, flowName: str) -> DescribeFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.describe_flow)
+        Provides a description of the specified flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.describe_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow)
         """
 
@@ -165,7 +185,9 @@ class AppflowClient:
         self, *, flowName: str, maxResults: int = None, nextToken: str = None
     ) -> DescribeFlowExecutionRecordsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
+        Fetches the execution history of the flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow_execution_records)
         """
 
@@ -177,7 +199,9 @@ class AppflowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#generate_presigned_url)
         """
 
@@ -189,7 +213,9 @@ class AppflowClient:
         entitiesPath: str = None
     ) -> ListConnectorEntitiesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.list_connector_entities)
+        Returns the list of available connector entities supported by Amazon AppFlow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.list_connector_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_connector_entities)
         """
 
@@ -197,37 +223,49 @@ class AppflowClient:
         self, *, maxResults: int = None, nextToken: str = None
     ) -> ListFlowsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.list_flows)
+        Lists all of the flows associated with your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.list_flows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_flows)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
+        Retrieves the tags that are associated with a specified flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_tags_for_resource)
         """
 
     def start_flow(self, *, flowName: str) -> StartFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.start_flow)
+        Activates an existing flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.start_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#start_flow)
         """
 
     def stop_flow(self, *, flowName: str) -> StopFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.stop_flow)
+        Deactivates the existing flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.stop_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#stop_flow)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.tag_resource)
+        Applies a tag to the specified flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.untag_resource)
+        Removes a tag from the specified flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#untag_resource)
         """
 
@@ -236,10 +274,12 @@ class AppflowClient:
         *,
         connectorProfileName: str,
         connectionMode: ConnectionModeType,
-        connectorProfileConfig: ConnectorProfileConfigTypeDef
+        connectorProfileConfig: "ConnectorProfileConfigTypeDef"
     ) -> UpdateConnectorProfileResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.update_connector_profile)
+        Updates a given connector profile associated with your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.update_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_connector_profile)
         """
 
@@ -254,6 +294,8 @@ class AppflowClient:
         sourceFlowConfig: "SourceFlowConfigTypeDef" = None
     ) -> UpdateFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/appflow.html#Appflow.Client.update_flow)
+        Updates an existing flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/appflow.html#Appflow.Client.update_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_flow)
         """
