@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     AggregationTypeType,
@@ -70,17 +70,26 @@ __all__ = (
     "ConnectorProfileCredentialsTypeDef",
     "ConnectorProfilePropertiesTypeDef",
     "ConnectorProfileTypeDef",
-    "CreateConnectorProfileResponseTypeDef",
-    "CreateFlowResponseTypeDef",
+    "CreateConnectorProfileRequestTypeDef",
+    "CreateConnectorProfileResponseResponseTypeDef",
+    "CreateFlowRequestTypeDef",
+    "CreateFlowResponseResponseTypeDef",
     "CustomerProfilesDestinationPropertiesTypeDef",
     "DatadogConnectorProfileCredentialsTypeDef",
     "DatadogConnectorProfilePropertiesTypeDef",
     "DatadogSourcePropertiesTypeDef",
-    "DescribeConnectorEntityResponseTypeDef",
-    "DescribeConnectorProfilesResponseTypeDef",
-    "DescribeConnectorsResponseTypeDef",
-    "DescribeFlowExecutionRecordsResponseTypeDef",
-    "DescribeFlowResponseTypeDef",
+    "DeleteConnectorProfileRequestTypeDef",
+    "DeleteFlowRequestTypeDef",
+    "DescribeConnectorEntityRequestTypeDef",
+    "DescribeConnectorEntityResponseResponseTypeDef",
+    "DescribeConnectorProfilesRequestTypeDef",
+    "DescribeConnectorProfilesResponseResponseTypeDef",
+    "DescribeConnectorsRequestTypeDef",
+    "DescribeConnectorsResponseResponseTypeDef",
+    "DescribeFlowExecutionRecordsRequestTypeDef",
+    "DescribeFlowExecutionRecordsResponseResponseTypeDef",
+    "DescribeFlowRequestTypeDef",
+    "DescribeFlowResponseResponseTypeDef",
     "DestinationConnectorPropertiesTypeDef",
     "DestinationFieldPropertiesTypeDef",
     "DestinationFlowConfigTypeDef",
@@ -105,9 +114,12 @@ __all__ = (
     "InforNexusConnectorProfileCredentialsTypeDef",
     "InforNexusConnectorProfilePropertiesTypeDef",
     "InforNexusSourcePropertiesTypeDef",
-    "ListConnectorEntitiesResponseTypeDef",
-    "ListFlowsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
+    "ListConnectorEntitiesRequestTypeDef",
+    "ListConnectorEntitiesResponseResponseTypeDef",
+    "ListFlowsRequestTypeDef",
+    "ListFlowsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
     "MarketoConnectorProfileCredentialsTypeDef",
     "MarketoConnectorProfilePropertiesTypeDef",
     "MarketoSourcePropertiesTypeDef",
@@ -115,6 +127,7 @@ __all__ = (
     "RedshiftConnectorProfileCredentialsTypeDef",
     "RedshiftConnectorProfilePropertiesTypeDef",
     "RedshiftDestinationPropertiesTypeDef",
+    "ResponseMetadataTypeDef",
     "S3DestinationPropertiesTypeDef",
     "S3OutputFormatConfigTypeDef",
     "S3SourcePropertiesTypeDef",
@@ -140,16 +153,22 @@ __all__ = (
     "SourceConnectorPropertiesTypeDef",
     "SourceFieldPropertiesTypeDef",
     "SourceFlowConfigTypeDef",
-    "StartFlowResponseTypeDef",
-    "StopFlowResponseTypeDef",
+    "StartFlowRequestTypeDef",
+    "StartFlowResponseResponseTypeDef",
+    "StopFlowRequestTypeDef",
+    "StopFlowResponseResponseTypeDef",
     "SupportedFieldTypeDetailsTypeDef",
+    "TagResourceRequestTypeDef",
     "TaskTypeDef",
     "TrendmicroConnectorProfileCredentialsTypeDef",
     "TrendmicroSourcePropertiesTypeDef",
     "TriggerConfigTypeDef",
     "TriggerPropertiesTypeDef",
-    "UpdateConnectorProfileResponseTypeDef",
-    "UpdateFlowResponseTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateConnectorProfileRequestTypeDef",
+    "UpdateConnectorProfileResponseResponseTypeDef",
+    "UpdateFlowRequestTypeDef",
+    "UpdateFlowResponseResponseTypeDef",
     "UpsolverDestinationPropertiesTypeDef",
     "UpsolverS3OutputFormatConfigTypeDef",
     "VeevaConnectorProfileCredentialsTypeDef",
@@ -371,21 +390,72 @@ ConnectorProfileTypeDef = TypedDict(
     total=False,
 )
 
-CreateConnectorProfileResponseTypeDef = TypedDict(
-    "CreateConnectorProfileResponseTypeDef",
+_RequiredCreateConnectorProfileRequestTypeDef = TypedDict(
+    "_RequiredCreateConnectorProfileRequestTypeDef",
     {
-        "connectorProfileArn": str,
+        "connectorProfileName": str,
+        "connectorType": ConnectorTypeType,
+        "connectionMode": ConnectionModeType,
+        "connectorProfileConfig": "ConnectorProfileConfigTypeDef",
+    },
+)
+_OptionalCreateConnectorProfileRequestTypeDef = TypedDict(
+    "_OptionalCreateConnectorProfileRequestTypeDef",
+    {
+        "kmsArn": str,
     },
     total=False,
 )
 
-CreateFlowResponseTypeDef = TypedDict(
-    "CreateFlowResponseTypeDef",
+
+class CreateConnectorProfileRequestTypeDef(
+    _RequiredCreateConnectorProfileRequestTypeDef, _OptionalCreateConnectorProfileRequestTypeDef
+):
+    pass
+
+
+CreateConnectorProfileResponseResponseTypeDef = TypedDict(
+    "CreateConnectorProfileResponseResponseTypeDef",
+    {
+        "connectorProfileArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateFlowRequestTypeDef = TypedDict(
+    "_RequiredCreateFlowRequestTypeDef",
+    {
+        "flowName": str,
+        "triggerConfig": "TriggerConfigTypeDef",
+        "sourceFlowConfig": "SourceFlowConfigTypeDef",
+        "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
+        "tasks": List["TaskTypeDef"],
+    },
+)
+_OptionalCreateFlowRequestTypeDef = TypedDict(
+    "_OptionalCreateFlowRequestTypeDef",
+    {
+        "description": str,
+        "kmsArn": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateFlowRequestTypeDef(
+    _RequiredCreateFlowRequestTypeDef, _OptionalCreateFlowRequestTypeDef
+):
+    pass
+
+
+CreateFlowResponseResponseTypeDef = TypedDict(
+    "CreateFlowResponseResponseTypeDef",
     {
         "flowArn": str,
         "flowStatus": FlowStatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredCustomerProfilesDestinationPropertiesTypeDef = TypedDict(
@@ -432,42 +502,157 @@ DatadogSourcePropertiesTypeDef = TypedDict(
     },
 )
 
-DescribeConnectorEntityResponseTypeDef = TypedDict(
-    "DescribeConnectorEntityResponseTypeDef",
+_RequiredDeleteConnectorProfileRequestTypeDef = TypedDict(
+    "_RequiredDeleteConnectorProfileRequestTypeDef",
+    {
+        "connectorProfileName": str,
+    },
+)
+_OptionalDeleteConnectorProfileRequestTypeDef = TypedDict(
+    "_OptionalDeleteConnectorProfileRequestTypeDef",
+    {
+        "forceDelete": bool,
+    },
+    total=False,
+)
+
+
+class DeleteConnectorProfileRequestTypeDef(
+    _RequiredDeleteConnectorProfileRequestTypeDef, _OptionalDeleteConnectorProfileRequestTypeDef
+):
+    pass
+
+
+_RequiredDeleteFlowRequestTypeDef = TypedDict(
+    "_RequiredDeleteFlowRequestTypeDef",
+    {
+        "flowName": str,
+    },
+)
+_OptionalDeleteFlowRequestTypeDef = TypedDict(
+    "_OptionalDeleteFlowRequestTypeDef",
+    {
+        "forceDelete": bool,
+    },
+    total=False,
+)
+
+
+class DeleteFlowRequestTypeDef(
+    _RequiredDeleteFlowRequestTypeDef, _OptionalDeleteFlowRequestTypeDef
+):
+    pass
+
+
+_RequiredDescribeConnectorEntityRequestTypeDef = TypedDict(
+    "_RequiredDescribeConnectorEntityRequestTypeDef",
+    {
+        "connectorEntityName": str,
+    },
+)
+_OptionalDescribeConnectorEntityRequestTypeDef = TypedDict(
+    "_OptionalDescribeConnectorEntityRequestTypeDef",
+    {
+        "connectorType": ConnectorTypeType,
+        "connectorProfileName": str,
+    },
+    total=False,
+)
+
+
+class DescribeConnectorEntityRequestTypeDef(
+    _RequiredDescribeConnectorEntityRequestTypeDef, _OptionalDescribeConnectorEntityRequestTypeDef
+):
+    pass
+
+
+DescribeConnectorEntityResponseResponseTypeDef = TypedDict(
+    "DescribeConnectorEntityResponseResponseTypeDef",
     {
         "connectorEntityFields": List["ConnectorEntityFieldTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeConnectorProfilesResponseTypeDef = TypedDict(
-    "DescribeConnectorProfilesResponseTypeDef",
+DescribeConnectorProfilesRequestTypeDef = TypedDict(
+    "DescribeConnectorProfilesRequestTypeDef",
+    {
+        "connectorProfileNames": List[str],
+        "connectorType": ConnectorTypeType,
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+DescribeConnectorProfilesResponseResponseTypeDef = TypedDict(
+    "DescribeConnectorProfilesResponseResponseTypeDef",
     {
         "connectorProfileDetails": List["ConnectorProfileTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeConnectorsRequestTypeDef = TypedDict(
+    "DescribeConnectorsRequestTypeDef",
+    {
+        "connectorTypes": List[ConnectorTypeType],
+        "nextToken": str,
     },
     total=False,
 )
 
-DescribeConnectorsResponseTypeDef = TypedDict(
-    "DescribeConnectorsResponseTypeDef",
+DescribeConnectorsResponseResponseTypeDef = TypedDict(
+    "DescribeConnectorsResponseResponseTypeDef",
     {
         "connectorConfigurations": Dict[ConnectorTypeType, "ConnectorConfigurationTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeFlowExecutionRecordsResponseTypeDef = TypedDict(
-    "DescribeFlowExecutionRecordsResponseTypeDef",
+_RequiredDescribeFlowExecutionRecordsRequestTypeDef = TypedDict(
+    "_RequiredDescribeFlowExecutionRecordsRequestTypeDef",
     {
-        "flowExecutions": List["ExecutionRecordTypeDef"],
+        "flowName": str,
+    },
+)
+_OptionalDescribeFlowExecutionRecordsRequestTypeDef = TypedDict(
+    "_OptionalDescribeFlowExecutionRecordsRequestTypeDef",
+    {
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
-DescribeFlowResponseTypeDef = TypedDict(
-    "DescribeFlowResponseTypeDef",
+
+class DescribeFlowExecutionRecordsRequestTypeDef(
+    _RequiredDescribeFlowExecutionRecordsRequestTypeDef,
+    _OptionalDescribeFlowExecutionRecordsRequestTypeDef,
+):
+    pass
+
+
+DescribeFlowExecutionRecordsResponseResponseTypeDef = TypedDict(
+    "DescribeFlowExecutionRecordsResponseResponseTypeDef",
+    {
+        "flowExecutions": List["ExecutionRecordTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeFlowRequestTypeDef = TypedDict(
+    "DescribeFlowRequestTypeDef",
+    {
+        "flowName": str,
+    },
+)
+
+DescribeFlowResponseResponseTypeDef = TypedDict(
+    "DescribeFlowResponseResponseTypeDef",
     {
         "flowArn": str,
         "description": str,
@@ -485,8 +670,8 @@ DescribeFlowResponseTypeDef = TypedDict(
         "createdBy": str,
         "lastUpdatedBy": str,
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DestinationConnectorPropertiesTypeDef = TypedDict(
@@ -788,28 +973,55 @@ InforNexusSourcePropertiesTypeDef = TypedDict(
     },
 )
 
-ListConnectorEntitiesResponseTypeDef = TypedDict(
-    "ListConnectorEntitiesResponseTypeDef",
+ListConnectorEntitiesRequestTypeDef = TypedDict(
+    "ListConnectorEntitiesRequestTypeDef",
+    {
+        "connectorProfileName": str,
+        "connectorType": ConnectorTypeType,
+        "entitiesPath": str,
+    },
+    total=False,
+)
+
+ListConnectorEntitiesResponseResponseTypeDef = TypedDict(
+    "ListConnectorEntitiesResponseResponseTypeDef",
     {
         "connectorEntityMap": Dict[str, List["ConnectorEntityTypeDef"]],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-ListFlowsResponseTypeDef = TypedDict(
-    "ListFlowsResponseTypeDef",
+ListFlowsRequestTypeDef = TypedDict(
+    "ListFlowsRequestTypeDef",
     {
-        "flows": List["FlowDefinitionTypeDef"],
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListFlowsResponseResponseTypeDef = TypedDict(
+    "ListFlowsResponseResponseTypeDef",
+    {
+        "flows": List["FlowDefinitionTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredMarketoConnectorProfileCredentialsTypeDef = TypedDict(
@@ -914,6 +1126,17 @@ class RedshiftDestinationPropertiesTypeDef(
     pass
 
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredS3DestinationPropertiesTypeDef = TypedDict(
     "_RequiredS3DestinationPropertiesTypeDef",
     {
@@ -1050,11 +1273,11 @@ _OptionalScheduledTriggerPropertiesTypeDef = TypedDict(
     "_OptionalScheduledTriggerPropertiesTypeDef",
     {
         "dataPullMode": DataPullModeType,
-        "scheduleStartTime": datetime,
-        "scheduleEndTime": datetime,
+        "scheduleStartTime": Union[datetime, str],
+        "scheduleEndTime": Union[datetime, str],
         "timezone": str,
         "scheduleOffset": int,
-        "firstExecutionFrom": datetime,
+        "firstExecutionFrom": Union[datetime, str],
     },
     total=False,
 )
@@ -1265,23 +1488,37 @@ class SourceFlowConfigTypeDef(_RequiredSourceFlowConfigTypeDef, _OptionalSourceF
     pass
 
 
-StartFlowResponseTypeDef = TypedDict(
-    "StartFlowResponseTypeDef",
+StartFlowRequestTypeDef = TypedDict(
+    "StartFlowRequestTypeDef",
+    {
+        "flowName": str,
+    },
+)
+
+StartFlowResponseResponseTypeDef = TypedDict(
+    "StartFlowResponseResponseTypeDef",
     {
         "flowArn": str,
         "flowStatus": FlowStatusType,
         "executionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-StopFlowResponseTypeDef = TypedDict(
-    "StopFlowResponseTypeDef",
+StopFlowRequestTypeDef = TypedDict(
+    "StopFlowRequestTypeDef",
+    {
+        "flowName": str,
+    },
+)
+
+StopFlowResponseResponseTypeDef = TypedDict(
+    "StopFlowResponseResponseTypeDef",
     {
         "flowArn": str,
         "flowStatus": FlowStatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 SupportedFieldTypeDetailsTypeDef = TypedDict(
@@ -1291,6 +1528,14 @@ SupportedFieldTypeDetailsTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Dict[str, str],
+    },
+)
+
 _RequiredTaskTypeDef = TypedDict(
     "_RequiredTaskTypeDef",
     {
@@ -1354,20 +1599,62 @@ TriggerPropertiesTypeDef = TypedDict(
     total=False,
 )
 
-UpdateConnectorProfileResponseTypeDef = TypedDict(
-    "UpdateConnectorProfileResponseTypeDef",
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
+UpdateConnectorProfileRequestTypeDef = TypedDict(
+    "UpdateConnectorProfileRequestTypeDef",
+    {
+        "connectorProfileName": str,
+        "connectionMode": ConnectionModeType,
+        "connectorProfileConfig": "ConnectorProfileConfigTypeDef",
+    },
+)
+
+UpdateConnectorProfileResponseResponseTypeDef = TypedDict(
+    "UpdateConnectorProfileResponseResponseTypeDef",
     {
         "connectorProfileArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateFlowRequestTypeDef = TypedDict(
+    "_RequiredUpdateFlowRequestTypeDef",
+    {
+        "flowName": str,
+        "triggerConfig": "TriggerConfigTypeDef",
+        "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
+        "tasks": List["TaskTypeDef"],
+    },
+)
+_OptionalUpdateFlowRequestTypeDef = TypedDict(
+    "_OptionalUpdateFlowRequestTypeDef",
+    {
+        "description": str,
+        "sourceFlowConfig": "SourceFlowConfigTypeDef",
     },
     total=False,
 )
 
-UpdateFlowResponseTypeDef = TypedDict(
-    "UpdateFlowResponseTypeDef",
+
+class UpdateFlowRequestTypeDef(
+    _RequiredUpdateFlowRequestTypeDef, _OptionalUpdateFlowRequestTypeDef
+):
+    pass
+
+
+UpdateFlowResponseResponseTypeDef = TypedDict(
+    "UpdateFlowResponseResponseTypeDef",
     {
         "flowStatus": FlowStatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredUpsolverDestinationPropertiesTypeDef = TypedDict(
